# Update debian
apt-get update; apt-get upgrade -y

# Installation of Docker
apt-get remove docker docker-engine docker.io containerd runc
apt-get install -y \
    apt-transport-https \
    ca-certificates \
    curl \
    gnupg2 \
    software-properties-common \
    htop \
    apache2-utils
curl -fsSL https://download.docker.com/linux/debian/gpg | apt-key add -
apt-key fingerprint 0EBFCD88
add-apt-repository \
   "deb [arch=amd64] https://download.docker.com/linux/debian \
   $(lsb_release -cs) \
   stable"
apt-get update
apt-get install -y docker-ce docker-ce-cli containerd.io

# Add Alias in bash
./docker/add-alias.sh

# Generate Docker Image for APIs
docker build -f docker/c2a-api.dockerfile -t c2a/api .

# Copy script to launch APIs
# Need to clone in /app/dev for dev and /app/prod for prod
mkdir /root/.bin
cp docker/script/start-api-dev.sh /root/.bin
cp docker/script/start-api-prod.sh /root/.bin

# Generate SSH key of the serveur
ssh-keygen -t rsa -b 4096 -C "c2a.toulouse@gmail.com"

# Install let's encrypt
git clone https://github.com/letsencrypt/letsencrypt /opt/letsencrypt

# Install node and NPM
apt-get update
apt-get install -y curl
curl -sL https://deb.nodesource.com/setup_10.x | bash -
apt-get install -y nodejs

# Launch Install Script
./docker/install-nginx.sh
./docker/install-gitlab.sh
./docker/install-gitea.sh
./docker/install-jenkins.sh
./docker/install-portainer.sh
./docker/install-mongo.sh

service nginx restart

# Configure git if someone push from the server
git config --global user.name "Serveur"
git config --global user.email "c2a.toulouse@gmail.com"
